@@ -56,6 +56,7 @@ from .core.config import (
     BaseConfig,
     PeopleCountingConfig,
     CustomerServiceConfig,
+    ProximityConfig,
     ZoneConfig,
     TrackingConfig,
     AlertConfig,
@@ -82,6 +83,7 @@ from .usecases.chicken_pose_detection import ChickenPoseDetectionConfig
 from .usecases.field_mapping import FieldMappingConfig, FieldMappingUseCase
 from .usecases.leaf_disease import LeafDiseaseDetectionConfig, LeafDiseaseDetectionUseCase
 from .usecases.parking import ParkingConfig
+from .usecases.abandoned_object_detection import AbandonedObjectConfig
 
 
 from .usecases.weld_defect_detection import WeldDefectConfig
@@ -115,7 +117,7 @@ from .usecases.windmill_maintenance import WindmillMaintenanceUseCase, WindmillM
 from .usecases.flower_segmentation import FlowerUseCase, FlowerConfig
 from .usecases.leaf import LeafConfig, LeafUseCase
 from .usecases.litter_monitoring import LitterDetectionUseCase,LitterDetectionConfig
-from .usecases.human_activity import HumanActivityUseCase, HumanActivityConfig
+from .usecases.human_activity_recognition import HumanActivityUseCase, HumanActivityConfig
 from .usecases.gas_leak_detection import GasLeakDetectionConfig, GasLeakDetectionUseCase
 
 #Put all IMAGE based usecases here
@@ -129,6 +131,7 @@ from .usecases.Histopathological_Cancer_Detection_img import HistopathologicalCa
 from .usecases import (
     PeopleCountingUseCase,
     CustomerServiceUseCase,
+    ProximityUseCase,
     AdvancedCustomerServiceUseCase,
     BasicCountingTrackingUseCase,
     LicensePlateUseCase,
@@ -177,6 +180,9 @@ from .usecases import (
     FlowerUseCase,
     SmokerDetectionUseCase,
     LitterDetectionUseCase,
+    AbandonedObjectDetectionUseCase,
+
+    HumanActivityUseCase,
 
     #Put all IMAGE based usecases here
     BloodCancerDetectionUseCase,
@@ -189,6 +195,7 @@ from .usecases import (
 # Register use cases automatically
 _people_counting = PeopleCountingUseCase()
 _customer_service = CustomerServiceUseCase()
+_proximity_detection = ProximityUseCase()
 _advanced_customer_service = AdvancedCustomerServiceUseCase()
 _basic_counting_tracking = BasicCountingTrackingUseCase()
 _license_plate = LicensePlateUseCase()
@@ -244,7 +251,8 @@ _flower_segmentation = FlowerUseCase()
 _leaf_det = LeafUseCase()
 _smoker_detection = SmokerDetectionUseCase()
 _litter_detection = LitterDetectionUseCase()
-_human_activity = HumanActivityUseCase()
+_abandoned_object_detection = AbandonedObjectDetectionUseCase()
+_human_activity_recognition = HumanActivityUseCase()
 _gas_leak_detection = GasLeakDetectionUseCase()
 
 
@@ -254,8 +262,10 @@ _skin_cancer_classification = SkinCancerClassificationUseCase()
 _plaque_segmentation = PlaqueSegmentationUseCase()
 _histopathological_cancer_detection = HistopathologicalCancerDetectionUseCase()
 
+registry.register_use_case(_abandoned_object_detection.category, _abandoned_object_detection.name, AbandonedObjectDetectionUseCase)
 registry.register_use_case(_litter_detection.category, _litter_detection.name, LitterDetectionUseCase)
 registry.register_use_case(_people_counting.category, _people_counting.name, PeopleCountingUseCase)
+registry.register_use_case(_proximity_detection.category, _proximity_detection.name, ProximityUseCase)
 registry.register_use_case(_customer_service.category, _customer_service.name, CustomerServiceUseCase)
 registry.register_use_case(_advanced_customer_service.category, _advanced_customer_service.name, AdvancedCustomerServiceUseCase)
 registry.register_use_case(_basic_counting_tracking.category, _basic_counting_tracking.name, BasicCountingTrackingUseCase)
@@ -313,7 +323,7 @@ registry.register_use_case(_flower_segmentation.category, _flower_segmentation.n
 registry.register_use_case(_parking_det.category, _parking_det.name, ParkingUseCase)
 registry.register_use_case(_leaf_det.category, _leaf_det.name, LeafUseCase)
 registry.register_use_case(_smoker_detection.category, _smoker_detection.name, SmokerDetectionUseCase)
-registry.register_use_case(_human_activity.category, _human_activity.name, HumanActivityUseCase)
+registry.register_use_case(_human_activity_recognition.category, _human_activity_recognition.name, HumanActivityUseCase)
 registry.register_use_case(_gas_leak_detection.category, _gas_leak_detection.name, GasLeakDetectionUseCase)
 
 #Put all IMAGE based usecases here
@@ -366,6 +376,8 @@ from .utils import (  # noqa: E402
     
     # New utilities
     create_people_counting_config,
+    create_intrusion_detection_config,
+    create_proximity_detection_config,
     create_customer_service_config,
     create_advanced_customer_service_config,
     create_basic_counting_tracking_config,
@@ -450,7 +462,8 @@ __all__ = [
     
     # Configuration classes
     'BaseConfig',
-    'PeopleCountingConfig', 
+    'PeopleCountingConfig',
+    'ProximityConfig', 
     'CustomerServiceConfig',
     'ColorDetectionConfig',
     'LicensePlateConfig',
@@ -504,6 +517,7 @@ __all__ = [
     'FlowerConfig',
     'SmokerDetectionConfig',
     'LitterDetectionConfig',
+    'AbandonedObjectConfig',
     'GasLeakDetectionConfig',
     'HumanActivityConfig',
 
@@ -516,6 +530,7 @@ __all__ = [
     # Use case classes
     'PeopleCountingUseCase',
     'CustomerServiceUseCase',
+    'ProximityUseCase',
     'AdvancedCustomerServiceUseCase',
     'BasicCountingTrackingUseCase',
     'LicensePlateUseCase',
@@ -566,6 +581,7 @@ __all__ = [
     'FlowerUseCase',
     'SmokerDetectionUseCase',
     'LitterDetectionUseCase',
+    'AbandonedObjectDetectionUseCase',
     'HumanActivityUseCase',
     'GasLeakDetectionUseCase',
 
@@ -633,6 +649,8 @@ __all__ = [
     
     # New utilities
     'create_people_counting_config',
+    'create_intrusion_detection_config',
+    'create_proximity_detection_config',
     'create_customer_service_config',
     'create_advanced_customer_service_config',
     'create_basic_counting_tracking_config',
