@@ -37,7 +37,7 @@ from ..utils import (
 
 @dataclass
 class FireSmokeConfig(BaseConfig):
-    confidence_threshold: float = 0.3
+    confidence_threshold: float = 0.05
 
     # Only fire and smoke categories included here (exclude normal)
     fire_smoke_categories: List[str] = field(
@@ -47,7 +47,15 @@ class FireSmokeConfig(BaseConfig):
         default_factory=lambda: ['fire']
     )
 
-    alert_config: Optional[AlertConfig] = None
+    alert_config: Optional[AlertConfig] = field(
+        default_factory=lambda: AlertConfig(
+            count_thresholds={"fire": 0},
+            alert_type=["email"],
+            alert_value=["FIRE_INFO@matrice.ai"],
+            alert_incident_category=["FIRE-ALERT"]
+        )
+    )
+    
 
     time_window_minutes: int = 60
     enable_unique_counting: bool = True
@@ -129,7 +137,7 @@ class FireSmokeUseCase(BaseProcessor):
             input_format = match_results_structure(data)
             context.input_format = input_format
             context.confidence_threshold = config.confidence_threshold
-            self.logger.info(f"Processing fire and smoke detection with format: {input_format.value}")
+            self.logger.info(f"Processing fire and smoke detection with format: {input_format.value} with threshold: {config.confidence_threshold}")
 
             # Step 2: Confidence thresholding
             processed_data = data
@@ -191,18 +199,16 @@ class FireSmokeUseCase(BaseProcessor):
                     frame_number = start_frame
 
              # Step 7: alerts
-            print("-----------------------------------------------")
-            print(config.confidence_threshold)
-            print(config.fire_smoke_categories)
-            print(config.index_to_category)
-            print(config.target_categories)
-            print(config.threshold_area)
-            print(config.alert_config)
-            print(config.alert_config.count_thresholds)
-            print(config.alert_config.alert_type)
-            print(config.alert_config.alert_value)
-            print(config.alert_config.alert_incident_category)
-            print("-----------------------------------------------")
+            # Ensure we have an AlertConfig object. `dataclasses.field` is only
+            # meant for class-level default declarations – using it at runtime
+            # produces a `Field` object which later breaks JSON serialization.
+            if config.alert_config is None:
+                config.alert_config = AlertConfig(
+                    count_thresholds={"fire": 0},
+                    alert_type=["email"],
+                    alert_value=["FIRE_INFO@matrice.ai"],
+                    alert_incident_category=["FIRE-ALERT"]
+                )
 
             alerts = self._check_alerts(fire_smoke_summary, frame_number, config, stream_info)
 
@@ -221,9 +227,16 @@ class FireSmokeUseCase(BaseProcessor):
 
             # Finalize context and return result
             context.processing_time = time.time() - start_time
-            # Extract frame-based dictionaries from the lists
+
             incidents = incidents_list[0] if incidents_list else {}
             tracking_stats = tracking_stats_list[0] if tracking_stats_list else {}
+            #EVENT ENDED SIGNAL
+
+            if len(tracking_stats_list)==3:
+                alerts = tracking_stats_list[1]
+                incidents = tracking_stats_list[2]
+                tracking_stats = tracking_stats_list[0]
+
             business_analytics = business_analytics_list[0] if business_analytics_list else {}
             summary = summary_list[0] if summary_list else {}
             agg_summary = {str(frame_number): {
@@ -241,7 +254,6 @@ class FireSmokeUseCase(BaseProcessor):
             usecase=self.name,
             category=self.category,
             context=context)
-
             return result
 
 
