@@ -98,7 +98,7 @@ class GasLeakDetectionUseCase(BaseProcessor):
         """
         start_time = time.time()
         # Ensure config is correct type
-        if not isinstance(config, GasDetectionConfig):
+        if not isinstance(config, GasLeakDetectionConfig):
             return self.create_error_result("Invalid config type", usecase=self.name, category=self.category,
                                             context=context)
         if context is None:
